summaryrefslogtreecommitdiffstats
path: root/ash/system/tray
diff options
context:
space:
mode:
authorantrim@chromium.org <antrim@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-05-13 14:19:43 +0000
committerantrim@chromium.org <antrim@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-05-13 14:19:43 +0000
commit3b68abc4bef8cc2a144cec2af0ce034fbd7f8c03 (patch)
tree504e0f16a8f919e0aebdf87e373959d988db5844 /ash/system/tray
parent39824c52f57acdc5adc625b7c5900c89fc42e351 (diff)
downloadchromium_src-3b68abc4bef8cc2a144cec2af0ce034fbd7f8c03.zip
chromium_src-3b68abc4bef8cc2a144cec2af0ce034fbd7f8c03.tar.gz
chromium_src-3b68abc4bef8cc2a144cec2af0ce034fbd7f8c03.tar.bz2
Fix reboot for update from tray.
BUG=224342 Review URL: https://chromiumcodereview.appspot.com/14639005 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@199728 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/system/tray')
-rw-r--r--ash/system/tray/system_tray_delegate.h4
-rw-r--r--ash/system/tray/test_system_tray_delegate.cc2
-rw-r--r--ash/system/tray/test_system_tray_delegate.h2
3 files changed, 4 insertions, 4 deletions
diff --git a/ash/system/tray/test_system_tray_delegate.cc b/ash/system/tray/test_system_tray_delegate.cc
index 89fc097..8299249 100644
--- a/ash/system/tray/test_system_tray_delegate.cc
+++ b/ash/system/tray/test_system_tray_delegate.cc
@@ -199,7 +199,7 @@ void TestSystemTrayDelegate::SignOut() {
void TestSystemTrayDelegate::RequestLockScreen() {
}
-void TestSystemTrayDelegate::RequestRestart() {
+void TestSystemTrayDelegate::RequestRestartForUpdate() {
}
void TestSystemTrayDelegate::GetAvailableBluetoothDevices(
diff --git a/ash/system/tray/test_system_tray_delegate.h b/ash/system/tray/test_system_tray_delegate.h
index 516e424..8f5f5c3 100644
--- a/ash/system/tray/test_system_tray_delegate.h
+++ b/ash/system/tray/test_system_tray_delegate.h
@@ -59,7 +59,7 @@ class TestSystemTrayDelegate : public SystemTrayDelegate {
virtual void ShutDown() OVERRIDE;
virtual void SignOut() OVERRIDE;
virtual void RequestLockScreen() OVERRIDE;
- virtual void RequestRestart() OVERRIDE;
+ virtual void RequestRestartForUpdate() OVERRIDE;
virtual void GetAvailableBluetoothDevices(BluetoothDeviceList* list) OVERRIDE;
virtual void BluetoothStartDiscovering() OVERRIDE;
virtual void BluetoothStopDiscovering() OVERRIDE;
diff --git a/ash/system/tray/system_tray_delegate.h b/ash/system/tray/system_tray_delegate.h
index 6f88605..ee0409e 100644
--- a/ash/system/tray/system_tray_delegate.h
+++ b/ash/system/tray/system_tray_delegate.h
@@ -217,8 +217,8 @@ class SystemTrayDelegate {
// Attempts to lock the screen.
virtual void RequestLockScreen() = 0;
- // Attempts to restart the system.
- virtual void RequestRestart() = 0;
+ // Attempts to restart the system for update.
+ virtual void RequestRestartForUpdate() = 0;
// Returns a list of available bluetooth devices.
virtual void GetAvailableBluetoothDevices(BluetoothDeviceList* devices) = 0;